import { ApplicationMethodTypeValues } from "../../../promotion";
import { StorePaymentCollection } from "../../payment";
import { StoreProduct, StoreProductVariant } from "../../product";
import { StoreRegion } from "../../region";
import { BaseCart, BaseCartAddress, BaseCartLineItem, BaseCartShippingMethod, BaseLineItemAdjustment, BaseLineItemTaxLine, BaseShippingMethodAdjustment, BaseShippingMethodTaxLine } from "../common";
export interface StoreCart extends Omit<BaseCart, "items"> {
    /**
     * The cart's shipping address.
     */
    shipping_address?: StoreCartAddress;
    /**
     * The cart's billing address.
     */
    billing_address?: StoreCartAddress;
    /**
     * The cart's items.
     */
    items?: StoreCartLineItem[];
    /**
     * The cart's shipping methods.
     */
    shipping_methods?: StoreCartShippingMethod[];
    /**
     * The cart's payment collection.
     */
    payment_collection?: StorePaymentCollection;
    /**
     * The cart's region
     */
    region?: StoreRegion;
    /**
     * The promotions applied to the cart.
     */
    promotions: StoreCartPromotion[];
}
export interface StoreCartLineItem extends Omit<BaseCartLineItem, "product" | "variant" | "cart"> {
    /**
     * The product this item is created for.
     */
    product?: StoreProduct;
    /**
     * The variant added to the cart.
     */
    variant?: StoreProductVariant;
    /**
     * The cart this item belongs to.
     */
    cart: StoreCart;
    /**
     * The item's tax lines.
     */
    tax_lines?: (BaseLineItemTaxLine & {
        item: StoreCartLineItem;
    })[];
    /**
     * The item's adjustments.
     */
    adjustments?: (BaseLineItemAdjustment & {
        item: StoreCartLineItem;
    })[];
}
export interface StoreCartAddress extends BaseCartAddress {
}
export interface StoreCartShippingMethod extends BaseCartShippingMethod {
    /**
     * The shipping method's tax lines.
     */
    tax_lines?: (BaseShippingMethodTaxLine & {
        shipping_method: StoreCartShippingMethod;
    })[];
    /**
     * The shipping method's adjustments.
     */
    adjustments?: (BaseShippingMethodAdjustment & {
        shipping_method: StoreCartShippingMethod;
    })[];
}
export interface StoreCartPromotion {
    /**
     * The promotion's ID.
     */
    id: string;
    /**
     * The promotion's code.
     */
    code?: string;
    /**
     * Whether the promotion is applied automatically (without the customer needing to enter a code).
     */
    is_automatic?: boolean;
    /**
     * How the promotion is applied.
     */
    application_method?: {
        /**
         * The amount to be discounted.
         */
        value: string;
        /**
         * The application method's type. If it's `fixed`, the promotion discounts a fixed amount.
         * If it's `percentage`, the promotion discounts a percentage.
         */
        type: ApplicationMethodTypeValues;
        /**
         * The currency code of the discount.
         *
         * @example usd
         */
        currency_code: string;
    };
}
//# sourceMappingURL=entities.d.ts.map